#pragma once
#include <string>
#include "../../YoggieEngine/src/Graphics/Primitives/Mesh.h"
#include "../../YoggieEngine/src/Graphics/Primitives/Texture.h"
#include "../../../YoggieEngine/src/Scene/UUID.h"
typedef uint64_t ASSET_UUID ;

enum class ASSET_TYPE {
	Unknown = -1,
	Mesh,
	Texture,
	Material
};

class Asset {
public:
	Asset(const char* name): ID(UUID::Generate()), name(std::string(name)) {}
	virtual ASSET_TYPE GetType() = 0;
protected:
	std::string& name;
	ASSET_UUID ID;

};

class MeshAsset : Asset {
public:
	MeshAsset(YoggieEngine::Mesh mesh) : Asset("New MeshAsset"), mesh(mesh) {}
	ASSET_TYPE  GetType() override { return ASSET_TYPE::Mesh; }
private:
	YoggieEngine::Mesh& mesh;
};

class TextureAsset : Asset {
public:
	TextureAsset (YoggieEngine::Texture texture): Asset("New TextureAsset"), texture(texture) {}
	ASSET_TYPE GetType() override { return ASSET_TYPE::Texture; }
private:
	YoggieEngine::Texture& texture;
};

class MaterialAsset : Asset {
public:
	MaterialAsset ()  : Asset("New MaterialAsset"){}
	ASSET_TYPE GetType() override { return ASSET_TYPE::Material; }
private:

};